@@ -4,10 +4,10 @@ snqProfitHessian <- function( beta, prices, weights,
 
    prices <- unlist( prices ) * scalingFactors
    normPrice <- sum( t( prices ) %*% weights )
-   Hessian <- beta / normPrice -
+   hessian <- beta / normPrice -
       beta %*% prices %*% t( weights ) / normPrice^2 -
       weights %*% t( prices ) %*% beta / normPrice^2 +
       weights %*% t( weights ) *
       mean( ( t( prices ) %*% beta %*% prices ) / normPrice^3 )
-   return( Hessian )
+   return( hessian )
 }
